@@ -29,6 +29,9 @@ from blazar.db import exceptions as db_exc
 from blazar.db.sqlalchemy import facade_wrapper
 from blazar.db.sqlalchemy import models
 
+RESOURCE_PROPERTY_MODELS = {
+    'physical:host': models.ComputeHostExtraCapability,
+}
 
 LOG = logging.getLogger(__name__)
 
@@ -663,26 +666,28 @@ def host_get_all_by_queries(queries):
 
             hosts_query = hosts_query.filter(filt)
         else:
-            # looking for extra capabilities matches
-            extra_filter = model_query(
-                models.ComputeHostExtraCapability, get_session()
-            ).filter(models.ComputeHostExtraCapability.capability_name == key
-                     ).all()
+            # looking for resource properties matches
+            extra_filter = (
+                _host_resource_property_query(get_session())
+                .filter(models.ResourceProperty.property_name == key)
+            ).all()
+
             if not extra_filter:
                 raise db_exc.BlazarDBNotFound(
                     id=key, model='ComputeHostExtraCapability')
 
-            for host in extra_filter:
+            for host, property_name in extra_filter:
+                print(dir(host))
                 if op in oper and oper[op][1](host.capability_value, value):
                     hosts.append(host.computehost_id)
                 elif op not in oper:
-                    msg = 'Operator %s for extra capabilities not implemented'
+                    msg = 'Operator %s for resource properties not implemented'
                     raise NotImplementedError(msg % op)
 
             # We must also avoid selecting any host which doesn't have the
             # extra capability present.
             all_hosts = [h.id for h in hosts_query.all()]
-            extra_filter_hosts = [h.computehost_id for h in extra_filter]
+            extra_filter_hosts = [h.computehost_id for h, _ in extra_filter]
             hosts += [h for h in all_hosts if h not in extra_filter_hosts]
 
     return hosts_query.filter(~models.ComputeHost.id.in_(hosts)).all()
@@ -755,9 +760,19 @@ def host_destroy(host_id):
 
 
 # ComputeHostExtraCapability
+
+def _host_resource_property_query(session):
+    return (
+        model_query(models.ComputeHostExtraCapability, session)
+        .join(models.ResourceProperty)
+        .add_column(models.ResourceProperty.property_name))
+
+
 def _host_extra_capability_get(session, host_extra_capability_id):
-    query = model_query(models.ComputeHostExtraCapability, session)
-    return query.filter_by(id=host_extra_capability_id).first()
+    query = _host_resource_property_query(session).filter(
+        models.ComputeHostExtraCapability.id == host_extra_capability_id)
+
+    return query.first()
 
 
 def host_extra_capability_get(host_extra_capability_id):
@@ -766,8 +781,10 @@ def host_extra_capability_get(host_extra_capability_id):
 
 
 def _host_extra_capability_get_all_per_host(session, host_id):
-    query = model_query(models.ComputeHostExtraCapability, session)
-    return query.filter_by(computehost_id=host_id)
+    query = _host_resource_property_query(session).filter(
+        models.ComputeHostExtraCapability.computehost_id == host_id)
+
+    return query
 
 
 def host_extra_capability_get_all_per_host(host_id):
@@ -777,6 +794,13 @@ def host_extra_capability_get_all_per_host(host_id):
 
 def host_extra_capability_create(values):
     values = values.copy()
+
+    resource_property = resource_property_get_or_create(
+        'physical:host', values.get('property_name'))
+
+    del values['property_name']
+    values['property_id'] = resource_property.id
+
     host_extra_capability = models.ComputeHostExtraCapability()
     host_extra_capability.update(values)
 
@@ -797,7 +821,7 @@ def host_extra_capability_update(host_extra_capability_id, values):
     session = get_session()
 
     with session.begin():
-        host_extra_capability = (
+        host_extra_capability, _ = (
             _host_extra_capability_get(session,
                                        host_extra_capability_id))
         host_extra_capability.update(values)
@@ -809,9 +833,8 @@ def host_extra_capability_update(host_extra_capability_id, values):
 def host_extra_capability_destroy(host_extra_capability_id):
     session = get_session()
     with session.begin():
-        host_extra_capability = (
-            _host_extra_capability_get(session,
-                                       host_extra_capability_id))
+        host_extra_capability = _host_extra_capability_get(
+            session, host_extra_capability_id)
 
         if not host_extra_capability:
             # raise not found error
@@ -819,15 +842,16 @@ def host_extra_capability_destroy(host_extra_capability_id):
                 id=host_extra_capability_id,
                 model='ComputeHostExtraCapability')
 
-        session.delete(host_extra_capability)
+        session.delete(host_extra_capability[0])
 
 
-def host_extra_capability_get_all_per_name(host_id, capability_name):
+def host_extra_capability_get_all_per_name(host_id, property_name):
     session = get_session()
 
     with session.begin():
         query = _host_extra_capability_get_all_per_host(session, host_id)
-        return query.filter_by(capability_name=capability_name).all()
+        return query.filter(
+            models.ResourceProperty.property_name == property_name).all()
 
 
 # FloatingIP reservation
@@ -1115,3 +1139,101 @@ def floatingip_destroy(floatingip_id):
             raise db_exc.BlazarDBNotFound(id=floatingip_id, model='FloatingIP')
 
         session.delete(floatingip)
+
+
+# Resource Properties
+
+def _resource_property_get(session, resource_type, property_name):
+    query = (
+        model_query(models.ResourceProperty, session)
+        .filter_by(resource_type=resource_type)
+        .filter_by(property_name=property_name))
+
+    return query.first()
+
+
+def resource_property_get(resource_type, property_name):
+    return _resource_property_get(get_session(), resource_type, property_name)
+
+
+def resource_properties_list(resource_type):
+    if resource_type not in RESOURCE_PROPERTY_MODELS:
+        raise db_exc.BlazarDBResourcePropertiesNotEnabled(
+            resource_type=resource_type)
+
+    session = get_session()
+
+    with session.begin():
+
+        resource_model = RESOURCE_PROPERTY_MODELS[resource_type]
+        query = session.query(
+            models.ResourceProperty.property_name,
+            models.ResourceProperty.private,
+            resource_model.capability_value).join(resource_model).distinct()
+
+        return query.all()
+
+
+def _resource_property_create(session, values):
+    values = values.copy()
+
+    resource_property = models.ResourceProperty()
+    resource_property.update(values)
+
+    with session.begin():
+        try:
+            resource_property.save(session=session)
+        except common_db_exc.DBDuplicateEntry as e:
+            # raise exception about duplicated columns (e.columns)
+            raise db_exc.BlazarDBDuplicateEntry(
+                model=resource_property.__class__.__name__,
+                columns=e.columns)
+
+    return resource_property_get(values.get('resource_type'),
+                                 values.get('property_name'))
+
+
+def resource_property_create(values):
+    return _resource_property_create(get_session(), values)
+
+
+def resource_property_update(resource_type, property_name, values):
+    if resource_type not in RESOURCE_PROPERTY_MODELS:
+        raise db_exc.BlazarDBResourcePropertiesNotEnabled(
+            resource_type=resource_type)
+
+    values = values.copy()
+    session = get_session()
+
+    with session.begin():
+        resource_property = _resource_property_get(
+            session, resource_type, property_name)
+
+        if not resource_property:
+            raise db_exc.BlazarDBInvalidResourceProperty(
+                property_name=property_name,
+                resource_type=resource_type)
+
+        resource_property.update(values)
+        resource_property.save(session=session)
+
+    return resource_property_get(resource_type, property_name)
+
+
+def _resource_property_get_or_create(session, resource_type, property_name):
+    resource_property = _resource_property_get(
+        session, resource_type, property_name)
+
+    if resource_property:
+        return resource_property
+    else:
+        rp_values = {
+            'resource_type': resource_type,
+            'property_name': property_name}
+
+        return resource_property_create(rp_values)
+
+
+def resource_property_get_or_create(resource_type, property_name):
+    return _resource_property_get_or_create(
+        get_session(), resource_type, property_name)
