@@ -14,7 +14,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import collections
 import datetime
 
 from novaclient import exceptions as nova_exceptions
@@ -303,9 +302,9 @@ class PhysicalHostPlugin(base.BasePlugin, nova.NovaClientWrapper):
         extra_capabilities = {}
         raw_extra_capabilities = (
             db_api.host_extra_capability_get_all_per_host(host_id))
-        for capability in raw_extra_capabilities:
-            key = capability['capability_name']
-            extra_capabilities[key] = capability['capability_value']
+        for capability, property_name in raw_extra_capabilities:
+            key = property_name
+            extra_capabilities[key] = capability.capability_value
         return extra_capabilities
 
     def get(self, host_id):
@@ -384,7 +383,7 @@ class PhysicalHostPlugin(base.BasePlugin, nova.NovaClientWrapper):
                 raise e
             for key in extra_capabilities:
                 values = {'computehost_id': host['id'],
-                          'capability_name': key,
+                          'property_name': key,
                           'capability_value': extra_capabilities[key],
                           }
                 try:
@@ -397,7 +396,7 @@ class PhysicalHostPlugin(base.BasePlugin, nova.NovaClientWrapper):
                     host=host['id'])
             return self.get_computehost(host['id'])
 
-    def is_updatable_extra_capability(self, capability):
+    def is_updatable_extra_capability(self, capability, property_name):
         reservations = db_utils.get_reservations_by_host_id(
             capability['computehost_id'], datetime.datetime.utcnow(),
             datetime.date.max)
@@ -414,7 +413,7 @@ class PhysicalHostPlugin(base.BasePlugin, nova.NovaClientWrapper):
             # the extra_capability.
             for requirement in requirements_queries:
                 # A requirement is of the form "key op value" as string
-                if requirement.split(" ")[0] == capability['capability_name']:
+                if requirement.split(" ")[0] == property_name:
                     return False
         return True
 
@@ -429,37 +428,33 @@ class PhysicalHostPlugin(base.BasePlugin, nova.NovaClientWrapper):
         new_keys = set(values.keys()) - set(previous_capabilities.keys())
 
         for key in updated_keys:
-            raw_capability = next(iter(
+            raw_capability, property_name = next(iter(
                 db_api.host_extra_capability_get_all_per_name(host_id, key)))
-            capability = {
-                'capability_name': key,
-                'capability_value': values[key],
-            }
-            if self.is_updatable_extra_capability(raw_capability):
+            capability = {'capability_value': values[key]}
+
+            if self.is_updatable_extra_capability(
+                    raw_capability, property_name):
                 try:
                     db_api.host_extra_capability_update(
                         raw_capability['id'], capability)
                 except (db_ex.BlazarDBException, RuntimeError):
-                    cant_update_extra_capability.append(
-                        raw_capability['capability_name'])
+                    cant_update_extra_capability.append(property_name)
             else:
                 LOG.info("Capability %s can't be updated because "
                          "existing reservations require it.",
-                         raw_capability['capability_name'])
-                cant_update_extra_capability.append(
-                    raw_capability['capability_name'])
+                         property_name)
+                cant_update_extra_capability.append(property_name)
 
         for key in new_keys:
             new_capability = {
                 'computehost_id': host_id,
-                'capability_name': key,
+                'property_name': key,
                 'capability_value': values[key],
             }
             try:
                 db_api.host_extra_capability_create(new_capability)
             except (db_ex.BlazarDBException, RuntimeError):
-                cant_update_extra_capability.append(
-                    new_capability['capability_name'])
+                cant_update_extra_capability.append(key)
 
         if cant_update_extra_capability:
             raise manager_ex.CantAddExtraCapability(
@@ -527,7 +522,9 @@ class PhysicalHostPlugin(base.BasePlugin, nova.NovaClientWrapper):
           'host-id': [
                        {
                          'lease_id': lease_id,
-                         'id': reservation_id
+                         'id': reservation_id,
+                         'start_date': lease_start_date,
+                         'end_date': lease_end_date,
                        },
                      ]
         }.
@@ -537,13 +534,17 @@ class PhysicalHostPlugin(base.BasePlugin, nova.NovaClientWrapper):
 
         # To reduce overhead, this method only executes one query
         # to get the allocation information
-        rsv_lease_host = db_utils.get_reservation_allocations_by_host_ids(
+        reservations = db_utils.get_reservation_allocations_by_host_ids(
             hosts, start, end, lease_id, reservation_id)
-
-        hosts_allocs = collections.defaultdict(list)
-        for rsv, lease, host in rsv_lease_host:
-            hosts_allocs[host].append({'lease_id': lease, 'id': rsv})
-        return hosts_allocs
+        host_allocs = {h: [] for h in hosts}
+        attributes_to_copy = ["id", "lease_id", "start_date", "end_date"]
+        for reservation in reservations:
+            for host_id in reservation['host_ids']:
+                if host_id in host_allocs.keys():
+                    host_allocs[host_id].append({
+                        k: v for k, v in reservation.items()
+                        if k in attributes_to_copy})
+        return host_allocs
 
     def allocation_candidates(self, values):
         self._check_params(values)
