@@ -29,6 +29,12 @@ from blazar.utils.openstack import base
 
 
 nova_opts = [
+    cfg.StrOpt('endpoint_type',
+               default='internal',
+               choices=['public', 'admin', 'internal'],
+               help='Type of the nova endpoint to use. This endpoint will be '
+                    'looked up in the keystone catalog and should be one of '
+                    'public, internal or admin.'),
     cfg.StrOpt('nova_client_version',
                default='2',
                deprecated_group='DEFAULT',
@@ -124,16 +130,19 @@ class BlazarNovaClient(object):
             endpoint_override = endpoint_override or \
                 base.url_for(ctx.service_catalog,
                              CONF.nova.compute_service,
+                             endpoint_interface=CONF.nova.endpoint_type,
                              os_region_name=CONF.os_region_name)
             auth_url = base.url_for(ctx.service_catalog, CONF.identity_service,
+                                    CONF.endpoint_type,
                                     os_region_name=CONF.os_region_name)
             kwargs.setdefault('global_request_id', ctx.global_request_id)
 
         if auth_url is None:
-            auth_url = "%s://%s:%s/%s" % (CONF.os_auth_protocol,
-                                          base.get_os_auth_host(CONF),
-                                          CONF.os_auth_port,
-                                          CONF.os_auth_prefix)
+            auth_url = "%s://%s:%s" % (CONF.os_auth_protocol,
+                                       base.get_os_auth_host(CONF),
+                                       CONF.os_auth_port)
+            if CONF.os_auth_prefix:
+                auth_url += "/%s" % CONF.os_auth_prefix
 
         if username:
             kwargs.setdefault('username', username)
@@ -150,6 +159,7 @@ class BlazarNovaClient(object):
             sess = session.Session(auth=auth)
             kwargs.setdefault('session', sess)
 
+        kwargs.setdefault('endpoint_type', CONF.nova.endpoint_type + 'URL')
         kwargs.setdefault('endpoint_override', endpoint_override)
         kwargs.setdefault('version', version)
         self.nova = nova_client.Client(**kwargs)
@@ -162,19 +172,7 @@ class BlazarNovaClient(object):
         return getattr(self.nova, name)
 
 
-# TODO(dbelova): remove these lines after novaclient 2.16.0 will be released
-class BlazarServer(servers.Server):
-    def unshelve(self):
-        """Unshelve -- Unshelve the server."""
-        self.manager.unshelve(self)
-
-
 class ServerManager(servers.ServerManager):
-    resource_class = BlazarServer
-
-    def unshelve(self, server):
-        """Unshelve the server."""
-        self._action('unshelve', server, None)
 
     def create_image(self, server, image_name=None, metadata=None):
         """Snapshot a server."""
@@ -289,7 +287,11 @@ class ReservationPool(NovaClientWrapper):
 
         """
 
-        agg = self.get_aggregate_from_name_or_id(pool)
+        try:
+            agg = self.get_aggregate_from_name_or_id(pool)
+        except manager_exceptions.AggregateNotFound:
+            LOG.warning("Aggregate '%s' not found, skipping deletion", pool)
+            return
 
         hosts = agg.hosts
         if len(hosts) > 0 and not force:
@@ -368,6 +370,15 @@ class ReservationPool(NovaClientWrapper):
                     except nova_exception.NotFound:
                         raise manager_exceptions.HostNotFound(host=host)
 
+                    # When moving a host out of the freepool, we need to
+                    # terminate preemptible instances before adding hosts to
+                    # the reservation aggregate, which makes them available for
+                    # scheduling.
+                    #
+                    # NOTE(priteau): Preemptibles should not be used with
+                    # instance reservation yet.
+                    self.terminate_preemptibles(host)
+
                 LOG.info("adding host '%(host)s' to aggregate %(id)s",
                          {'host': host, 'id': agg.id})
                 try:
@@ -380,12 +391,12 @@ class ReservationPool(NovaClientWrapper):
                         pool=pool, host=host, nova_exception=str(e))
         except Exception as e:
             if added_hosts:
-                LOG.warn('Removing hosts added to aggregate %s: %s',
-                         agg.id, added_hosts)
+                LOG.warning('Removing hosts added to aggregate %s: %s',
+                            agg.id, added_hosts)
                 for host in added_hosts:
                     self.nova.aggregates.remove_host(agg.id, host)
             if removed_hosts:
-                LOG.warn('Adding hosts back to freepool: %s', removed_hosts)
+                LOG.warning('Adding hosts back to freepool: %s', removed_hosts)
                 for host in removed_hosts:
                     self.nova.aggregates.add_host(freepool_agg.id, host)
             raise e
@@ -458,6 +469,20 @@ class ReservationPool(NovaClientWrapper):
         metadata = {project_id: None}
         return self.nova.aggregates.set_metadata(agg.id, metadata)
 
+    def terminate_preemptibles(self, host):
+        """Terminate preemptible instances running on host"""
+        for server in self.nova.servers.list(
+                search_opts={"host": host, "all_tenants": 1}):
+            try:
+                LOG.info('Terminating preemptible instance %s (%s)',
+                         server.name, server.id)
+                self.nova.servers.delete(server=server)
+            except nova_exception.NotFound:
+                LOG.info('Could not find server %s, may have been deleted '
+                         'concurrently.', server)
+            except Exception as e:
+                LOG.exception('Failed to delete %s: %s.', server, str(e))
+
 
 class NovaInventory(NovaClientWrapper):
 
